@@ -67,11 +67,12 @@ class ZebrunnerAPI(metaclass=Singleton):
             service_url (str): Url to access Zebrunner API. None by default.
             access_token (str): Access token to access Zebrunner API. None by default.
         """
-        self.service_url = service_url.rstrip("/") if service_url else ""
-        self.access_token = access_token
-        self._client = Client()
-        self._auth_token = None
-        self.authenticated = False
+        if service_url and access_token:
+            self.service_url = service_url.rstrip("/")
+            self.access_token = access_token
+            self._client = Client()
+            self._auth_token = None
+            self.authenticated = False
 
     def _sign_request(self, request: Request) -> Request:
         """
